*****************
Flow, Series, Var
*****************

.. |br| raw:: html

   <br />

.. automodule:: aristopy.flowSeriesVar

Flow
==========

.. autoclass:: Flow
   :members:
   :undoc-members:
   

Series
==========

.. autoclass:: Series
   :members:
   :undoc-members:
   
   
Var (Variable)
==============

.. autoclass:: Var
   :members:
   :undoc-members: